==> libgtk-java-2.4.7.1.tar.gz: libgtk-java-2.4.7.1/src/java/org/gnu/gdk/Rectangle.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

 /*
  * TODO:
  * - Documentation:
  * - Look through the api and implement the last 2 methods.
  */

package org.gnu.gdk;
import org.gnu.glib.Boxed;
public class Rectangle extends Boxed 
{
	
	public Rectangle(int handle){
		this.handle=handle;
	}
	
	public int getX(){
		return Rectangle.getX(handle);
	}
	
	public void setX(int x){
		setX(handle,x);		
	}
	
	public int getY(){
		return Rectangle.getY(handle);
	}
	
	public void setY(int y){
		setY(handle,y);
	}
	
	public int getWidth(){
		return Rectangle.getWidth(handle);
	}
	
	public void setWidth(int width){
		setWidth(handle,width);
	}
	
	public int getHeight(){
		return Rectangle.getHeight(handle);
	}
	
	public void setHeight(int heigth){
		setHeight(handle,heigth);
	}
	
	// Not sure if it must be its behaviour.
	// Incomplete.
	public Rectangle intersect(Rectangle src1,Rectangle src2){
		//Rectangle.gdk_rectangle_intersect(src1.getHandle(),src2.getHandle(),
		return null;
	}
	
	// The same as the previous.
	//	must look api.
	public Rectangle union(Rectangle src1,Rectangle src2){
		return null;
	}
		
    /****************************************
     * BEGINNING OF GENERATED CODE
     ****************************************/
    native static final protected int getX (int obj);
    native final protected void setX (int obj, int x);
    native static final protected int getY (int obj);
    native final protected void setY (int obj, int y);
    native static final protected int getWidth (int obj);
    native final protected void setWidth (int obj, int width);
    native static final protected int getHeight (int obj);
    native final protected void setHeight (int obj, int height);
    native static final protected int gdk_rectangle_intersect (int src1, int src2, int dest);
    native static final protected void gdk_rectangle_union (int src1, int src2, int dest);
    /****************************************
     * END OF GENERATED CODE
     ****************************************/
}

==> libgtk-java-2.5.3.tar.gz: libgtk-java-2.5.3/src/java/org/gnu/gdk/Rectangle.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

 /*
  * TODO:
  * - Documentation:
  * - Look through the api and implement the last 2 methods.
  */

package org.gnu.gdk;
import org.gnu.glib.Boxed;
import org.gnu.glib.Handle;
public class Rectangle extends Boxed 
{
	
	public Rectangle(Handle handle){
		this.handle=handle;
	}
	
	public int getX(){
		return Rectangle.getX(handle);
	}
	
	public void setX(int x){
		setX(handle,x);		
	}
	
	public int getY(){
		return Rectangle.getY(handle);
	}
	
	public void setY(int y){
		setY(handle,y);
	}
	
	public int getWidth(){
		return Rectangle.getWidth(handle);
	}
	
	public void setWidth(int width){
		setWidth(handle,width);
	}
	
	public int getHeight(){
		return Rectangle.getHeight(handle);
	}
	
	public void setHeight(int heigth){
		setHeight(handle,heigth);
	}
	
	// Not sure if it must be its behaviour.
	// Incomplete.
	public Rectangle intersect(Rectangle src1,Rectangle src2){
		//Rectangle.gdk_rectangle_intersect(src1.getHandle(),src2.getHandle(),
		return null;
	}
	
	// The same as the previous.
	//	must look api.
	public Rectangle union(Rectangle src1,Rectangle src2){
		return null;
	}
		
    native static final protected int getX (Handle obj);
    native final protected void setX (Handle obj, int x);
    native static final protected int getY (Handle obj);
    native final protected void setY (Handle obj, int y);
    native static final protected int getWidth (Handle obj);
    native final protected void setWidth (Handle obj, int width);
    native static final protected int getHeight (Handle obj);
    native final protected void setHeight (Handle obj, int height);
    native static final protected boolean gdk_rectangle_intersect (Handle src1, Handle src2, Handle dest);
    native static final protected void gdk_rectangle_union (Handle src1, Handle src2, Handle dest);
}
